import unittest
from seesaw.util import find_executable, unique_id_str
import seesaw


class UtilTest(unittest.TestCase):
    def test_find_executable(self):
        self.assertTrue(find_executable(
            'pipeline runner',
            seesaw.__version__,
            ['./run-pipeline', '../run-pipeline'],
            version_arg='--version')
        )

    def test_find_executable_bad_version(self):
        self.assertFalse(find_executable(
            'pipeline runner',
            '123-notrealversion',
            ['./run-pipeline', '../run-pipeline'],
            version_arg='--version')
        )

    def test_unique_id_str(self):
        # check for no crash
        self.assertTrue(unique_id_str())



#!/usr/bin/env python

"""
distutils/setuptools install script. See inline comments for packaging documentation.
"""

import os
import sys

import seesaw

try:
    from setuptools import setup
    # hush pyflakes
    setup
except ImportError:
    from distutils.core import setup

try:
    from distutils.command.build_py import build_py_2to3 as build_py
except ImportError:
    from distutils.command.build_py import build_py

packages = [
    'seesaw'
]

package_dir = {
    'seesaw': 'seesaw'
}

package_data = {
    'seesaw': [
        'public/index.html',
        'public/*.js',
        'public/*.css',
        'templates/*.html'
    ]
}

scripts = [
    'run-pipeline',
    'run-warrior'
]

requires = [
    'argparse',
    'ordereddict',
    'Tornado>=2.3',
    'tornadio2>=0.0.3'
]

setup(
    name='seesaw',
    version=seesaw.__version__,
    maintainer='ArchiveTeam',
    maintainer_email='warrior@archiveteam.org',
    description='ArchiveTeam seesaw kit',
    long_description=open('README.md', 'rt').read(),
    url='http://www.archiveteam.org/',
    packages=packages,
    package_dir=package_dir,
    package_data=package_data,
    include_package_data=True,
    scripts=scripts,
    install_requires=requires,
    cmdclass={'build_py': build_py}
)



# TODO: i'm not sure why we need all
__all__ = ['config', 'event', 'externalprocess', 'item', 'pipeline', 'project', 'runner', 'util', 'task', 'tracker', 'warrior', 'web']

__title__ = 'seesaw'
__version__ = '0.1.7'
__build__ = 0x00107
runner_type = ""
warrior_build = ""
